# dask-opentelemetry

[![PyPI - Version](https://img.shields.io/pypi/v/dask-opentelemetry.svg)](https://pypi.org/project/dask-opentelemetry)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/dask-opentelemetry.svg)](https://pypi.org/project/dask-opentelemetry)

-----

**Table of Contents**

- [dask-opentelemetry](#dask-opentelemetry)
  - [Installation](#installation)
  - [License](#license)

## Installation

```console
pip install dask-opentelemetry
```

## License

`dask-opentelemetry` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
